@@ -1,19 +1,7 @@
 """This module contains exceptions raised by MythX."""
 
 
-class MythXBaseException(Exception):
-    """A base exception describing MythX-related errors."""
-
-    pass
-
-
-class ValidationError(ValueError):
-    """An exception denoting an error in SerDe of request or response data."""
-
-    pass
-
-
-class MythXAPIError(MythXBaseException):
+class MythXAPIError(Exception):
     """An exception denoting an API-related error.
 
     This is usually raised when the API takes too long to respond, or a
