@@ -1,6 +1,6 @@
 """This module contains the AnalysisInputResponse domain model."""
 
-from mythx_models.request.analysis_submission import AnalysisSubmissionRequest
+from mythx_models.request import AnalysisSubmissionRequest
 
 
 class AnalysisInputResponse(AnalysisSubmissionRequest):
